# This is a module

__version__ = "1.0"

def funchello():
    print "Hello world from file '%s'" % __file__
    print "This is version '%s'" % __version__

if __name__ == '__main__':
    # A simple file test
    funchello()



#!/usr/bin/env python

from distutils.core import setup

setup(name='minpypihello',
      version='1.1',
      description='Minimal PyPI Package Example',
      author='Pili Hu',
      author_email='me@hupili.net',
      url='https://github.com/hupili/min-pypi-hello',
      license="MIT",
      packages=['minpypihello'],
      scripts=['myhello']
     )
